@@ -3,7 +3,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use Class::Accessor::Lite (
     ro => [qw/connect_info/],
@@ -38,7 +38,7 @@ sub _deflate_param {
 
 sub _inflate_rows {
     my ($self, $table, @rows) = @_;
-    @rows = $self->{inflate} ? map {$self->{inflate}->($_, $table)} @rows : @rows;
+    @rows = $self->{inflate} ? map {$self->{inflate}->($_, $table)} grep {defined $_} @rows : @rows;
     wantarray ? @rows : $rows[0];
 }
 
